%{
◆◇ RC造十字形柱梁接合部の曲げ強度算出プログラム ◇◆
RC_joint_zyuzi: originally coded by Kazuhiro Mizumoto
・ファイル名r○aでは，上端・下端それぞれについてMjを計算し，Mj（上段）とMj（下段）の平均を最終的なMjとする
・ファイル名r○bでは，上端・下端それぞれについて主筋断面積・主筋間距離比を求め，その平均を取った後にMjを求める
・ファイル名vir(virtual)では，仮想実大部材を解析
・ファイル名exp(experiment)では，実験研究論文の縮小試験体を解析

【ひずみの適合条件の取り扱い】
・flg = 0 or 1：ひずみの適合条件を考慮しない or 考慮する

■ 主な変更点【重要】2022/05/19
・Mjb6, Mju6：ひずみの適合条件を考慮した接合部曲げ強度の計算（flg = 1のとき）
　　↑計算方法は，楠原・塩原(2010)式(6)に基づく。
・Mjb9, Mju9：建研(2020)による接合部曲げ強度の計算（case2の計算方法）
　　↑計算方法は，楠原・塩原(2010)式(9),(10)に基づく。ひずみの適合条件は考慮しない。

■ 修正履歴
date: 2020/10/05 初版作成
date: 2021/06/07 Excelデータの接合部横補強筋の断面積の読み取り方法を修正
date: 2021/06/08 Excelに出力する最後の列に接合部降伏強度Mjyを追加
date: 2022/02/02 変数や関数をト形の体裁に合わせる
date: 2022/02/11 ひずみの適合条件を考慮して接合部横補強筋と柱中段筋の応力を求める
date: 2022/05/19 建研(2020)による接合部曲げ強度の計算方法を採用
date: 2022/06/03 応力ブロックにより求めた梁，柱の曲げ終局強度を計算結果に追加
%}

% ◆◇ 変数の読込み ◇◆ ---------------------------------------------------
% プログラムの体裁
tic                 % ストップウォッチタイマーを開始（現在の時刻を記録）
clear all           % ワークスペースからすべての変数を削除
close all           % 現在のFigureを削除
addpath('./func');  % 検索パスにフォルダーを追加

% ◆◇ 要変更箇所 ◇◆ ----------------------------------------------------
% ひずみの適合条件の考慮の有無
% flg = 0;  % ひずみの適合条件を考慮しない
flg = 1;  % ひずみの適合条件を考慮する

% 柱の曲げ終局強度の略算式の計算方法
opt = 0;  % 1段配筋の式を使用しない（pg式のみ）
% opt = 1;  % 1段配筋の式を使用する（pt式とpg式を併用）
% -------------------------------------------------------------------------

% ファイルの読込み
directory = pwd;                  % pwd(print working directory)：現在作業中のディレクトリをパスを通す
filename = 'dataset-v2r53.xlsx';  % Excelのファイル名
fp = [directory,'\',filename];    % Excelファイルの場所を指定
read_table = readtable(fp,'basic',true,'PreserveVariableNames',true);  % Excelデータの読み取り
table_size = size(read_table);    % Excelデータの表のサイズ

% Excelからの変数の読込み
Cname = num2alphabet(table_size(2));                                                  % 文字列の読み取り
dataset = readtable(fp,'basic',true,'Range',['A5:',Cname,num2str(table_size(1)+5)]);  % Excelのデータセット
n = table_size(1);                                                                    % データの個数

% ExcelからMATLABの変数にデータ入力（input_data.mのfunctionから，datasetを引数としてデータ入力を実行）
[no,fc_b,fc_c,fc,L,Nb,b_b,Db,a_b,sigma_by,Esb, ...
    n_top1b,d_top1b,n_top2b,d_top2b,n_btm1b,d_btm1b,n_btm2b,d_btm2b, ...
    H,Nc,b_c,Dc,a_c,sigma_cy,Esc, ...
    n_top1c,d_top1c,n_top2c,d_top2c,n_btm1c,d_btm1c,n_btm2c,d_btm2c, ...
    n_m,n_h,a_h,sigma_hy] = input_data_r2(dataset,n);
% -------------------------------------------------------------------------

% ◆◇ 梁，柱の曲げ終局強度の計算 ◇◆ --------------------------------------
% 梁の曲げ終局強度
[at_topb,Tu_by] = Ty(n_top1b,n_top2b,a_b,sigma_by);  % 梁上段筋の全断面積[mm2]と降伏強度[N]
[at_btmb,Tl_by] = Ty(n_btm1b,n_btm2b,a_b,sigma_by);  % 梁下段筋の全断面積[mm2]と降伏強度[N]
[d_topb,d_btmb,~] = g(n_top1b,n_top2b,d_top1b,d_top2b,n_btm1b,n_btm2b,d_btm1b,d_btm2b,Db);
Mu_topb = 0.9*at_topb.*sigma_by.*(Db-d_topb);  % 梁上段筋を代入した曲げ終局強度[N・mm]（2015年版黄色本：p.651，式(付1.3-5)）
Mu_btmb = 0.9*at_btmb.*sigma_by.*(Db-d_btmb);  % 梁下段筋を代入した曲げ終局強度[N・mm]（2015年版黄色本：p.651，式(付1.3-5)）
Mu_b = (Mu_topb+Mu_btmb)/2;                    % 梁の曲げ終局強度[N･mm]，上段筋と下段筋の場合とで平均をとる

% 柱の曲げ終局強度（Mu_c.mのfunctionから計算式を引用）
ag_c = (n_top1c+n_top2c+n_btm1c+n_btm2c+n_m).*a_c;  % 柱主筋の全断面積[mm2]
at_c = ag_c/2;                                      % 柱主筋の全断面積の半分の値[mm2]，中断筋がないと引張主筋の断面積atになる
% 後の接合部で使うAcは，柱上段筋の全断面積[mm2]だが，中断筋は計算に含まれないことに注意
d_topc = (n_top1c.*d_top1c+n_top2c.*(d_top1c+d_top2c)+n_m/2.*Dc/2)./(n_top1c+n_top2c+n_m/2);
% d_topc = zeros(n,1);
% for i = 1:n
%     d_topc(i) = g1_func(i,n,Dc,n_top1c,d_top1c,n_top2c,d_top2c, ...
%         d_btm1c,d_btm2c,n_m);
% end
g1 = (Dc-d_topc*2)./Dc;                             % 後の接合部で使うgcは，中断筋は計算に含まれないことに注意
[Nmax_c,Nmin_c,Nb_c,Mu_c,Mc_index] = Mu_c4(opt,n,b_c,Dc,fc_c,g1,at_c,ag_c,sigma_cy,n_top2c,n_btm2c,n_m,Nc);

% 応力ブロックを用いた柱梁曲げ強度
% 梁の曲げ終局強度
Mu1 = zeros(n,1); Mu2 = zeros(n,1); m = zeros(n,1);
MbufACI = zeros(n,1); MbunACI = zeros(n,1);
sL = (L-Dc)./2;
for iw = 1:n
    % 上端を圧縮縁とする場合
    [pi,di]=jointDB2csec(b_b(iw),Db(iw),a_b(iw),...
        n_top1b(iw),n_top2b(iw),n_btm1b(iw),n_btm2b(iw),0,...
        d_top1b(iw),d_top2b(iw),d_btm1b(iw),d_btm2b(iw));
    [Mu1(iw),m(iw)]=MNstrsblk(b_b(iw),Db(iw),fc_b(iw),0.003,sigma_by(iw),Esb(iw),...
        Nb(iw),pi,di);
    
    % 下端を圧縮縁とする場合
    [pi,di]=jointDB2csec(b_b(iw),Db(iw),a_b(iw),...
        n_btm1b(iw),n_btm2b(iw),n_top1b(iw),n_top2b(iw),0,...
        d_btm1b(iw),d_btm2b(iw),d_top1b(iw),d_top2b(iw));
    [Mu2(iw),m(iw)]=MNstrsblk(b_b(iw),Db(iw),fc_b(iw),0.003,sigma_by(iw),Esb(iw),...
        Nb(iw),pi,di);
    
    % 上端と下端の平均をとる
    MbufACI(iw) = (Mu1(iw)+Mu2(iw))/2;
    MbunACI(iw) = MbufACI(iw)*L(iw)/2/sL(iw);
end

% 柱の曲げ終局強度
Mu = zeros(n,1); m = zeros(n,1);
McufACI = zeros(n,1); McunACI = zeros(n,1);
sH = (H-Db)./2;
for iw = 1:n
    [pi,di]=jointDB2csec(b_c(iw),Dc(iw),a_c(iw),...
        n_top1c(iw),n_top2c(iw),n_btm1c(iw),n_btm2c(iw),n_m(iw),...
        d_top1c(iw),d_top2c(iw),d_btm1c(iw),d_btm2c(iw));
    [Mu(iw),m(iw)]=MNstrsblk(b_c(iw),Dc(iw),fc_c(iw),0.003,sigma_cy(iw),Esc(iw),...
        Nc(iw),pi,di);
    McufACI(iw) = Mu(iw);
    McunACI(iw) = Mu(iw)*H(iw)/2/sH(iw);
end
% -------------------------------------------------------------------------

% ◆◇ 接合部曲げ強度の理論値の計算 ◇◆ ------------------------------------
% 柱中断筋の本数の変更
% 元のExcelデータに入っている配筋の本数を，楠原・塩原論文2010，p.2033に基づき変更する
for i = 1:n
    if d_top1c(i)+d_top2c(i) > Dc(i)/4
        n_m(i) = n_m(i)+n_top2c(i);
        n_top2c(i) = 0;
    end
    if d_btm1c(i)+d_btm2c(i) > Dc(i)/4
        n_m(i) = n_m(i)+n_btm2c(i);
        n_btm2c(i) = 0;
    end
end

% 上下対称を仮定した梁の主筋間距離比gb[-]（g.mのfunctionから計算式を引用）
[~,~,gu_b] = g(n_top1b,n_top2b,d_top1b,d_top2b,n_top1b,n_top2b,d_top1b,d_top2b,Db);
[~,~,gl_b] = g(n_btm1b,n_btm2b,d_btm1b,d_btm2b,n_btm1b,n_btm2b,d_btm1b,d_btm2b,Db);
gb = (gu_b+gl_b)/2;

% 柱の主筋間距離比gc[-]（g.mのfunctionから計算式を引用）
[d_topc,d_btmc,gc] = g(n_top1c,n_top2c,d_top1c,d_top2c,n_btm1c,n_btm2c,d_btm1c,d_btm2c,Dc);

% 接合部横補強筋及び柱中断筋の断面積と降伏強度（Ty.mのfunctionから計算式を引用）
[ag_h,Thy] = Ty(n_h,0,a_h,sigma_hy);  % 柱横補強筋の全断面積[mm2]と降伏強度[N]
a_m = a_c;                            % 柱中断筋1本当たりの公称断面積[mm2]
sigma_my = sigma_cy;                  % 柱中断筋の降伏強度[N/mm2]
[ag_m,Tmy] = Ty(n_m,0,a_m,sigma_my);  % 柱中断筋の全断面積[mm2]と降伏強度[N]

% 接合部モーメント算出の準備（beta1.mとTy.mのfunctionから計算式を引用）
beta1 = beta1(n,fc);       % β1の算出
beta3 = 0.85;              % コンクリートストレスブロック（等価応力度ブロック）高さのコンクリート圧縮強度に対する比[-]
eps_by = sigma_by./Esb;    % 梁主筋のひずみ[-]
eps_cy = sigma_cy./Esc;    % 柱主筋のひずみ[-]
eps_u = 0.003;             % コンクリートの終局ひずみ[-]（楠原・塩原論文2010：p.2033，右下文中）
R = Db./Dc;                % 接合部アスペクト比[-]
sL = (L-Dc)/2;             % スパンの内法（うちのり）長さハーフ[mm]
sH = (H-Db)/2;             % 階高の内法（うちのり）長さハーフ[mm]
Ab = (at_topb+at_btmb)/2;  % 梁主筋の断面積[mm2]
Tby = sigma_by.*Ab;        % 梁主筋の降伏強度[N]
[Ac,Tcy] = Ty(n_top1c,n_top2c,a_c,sigma_cy);  % 柱主筋の断面積[mm2]と柱主筋の降伏強度[N]

% ■ 接合部曲げ強度の計算：式(6)と式(9)は同じ計算結果になる-------------------
Vb = Mu_b./L;  % 梁のせん断力（今はVbの初期値であり，仮に設定している。真のVbは次の関数Mjで収束計算をする）
Vc = Mu_c./H;  % 柱のせん断力（今はVcの初期値であり，仮に設定している。真のVcは次の関数Mjで収束計算をする）

% 接合部の釣合モーメント：式(6)（Mjb6_func.mのfunctionから計算式を引用）
[Mjb6_1,Tbb6_1,Tcb6_1,Th1,Tm1,xi1_1] = Mjb6_func2(n,flg,at_topb,Ac,b_b,b_c,beta1,beta3,Db,Dc, ...
    eps_u,Esb,Esc,fc,gu_b,gc,H,L,Nb,Nc,R,Tu_by,Tcy,Thy,Tmy,Vb,Vc);
[Mjb6_2,Tbb6_2,Tcb6_2,Th2,Tm2,xi1_2] = Mjb6_func2(n,flg,at_btmb,Ac,b_b,b_c,beta1,beta3,Db,Dc, ...
    eps_u,Esb,Esc,fc,gl_b,gc,H,L,Nb,Nc,R,Tl_by,Tcy,Thy,Tmy,Vb,Vc);
Mjb6 = (Mjb6_1+Mjb6_2)/2;
xi1 = (xi1_1+xi1_2)/2;

% 接合部の釣合モーメント：式(9)（Mjb9_func.mのfunctionから計算式を引用）
% case2
[gamma_hb1,gamma_vb1,Mjb9_1,Mjhb1,Mjvb1,~,~,xi19_1] = Mjb9_func0(n, ...
    at_topb,Ac,b_b,b_c,beta1,beta3,Db,Dc,eps_u,Esb,Esc,fc,gu_b,gc,H,L,Nb,Nc,R, ...
    Tu_by,Tcy,zeros(n,1),zeros(n,1),zeros(n,1),zeros(n,1));
[gamma_hb2,gamma_vb2,Mjb9_2,Mjhb2,Mjvb2,~,~,xi19_2] = Mjb9_func0(n, ...
    at_btmb,Ac,b_b,b_c,beta1,beta3,Db,Dc,eps_u,Esb,Esc,fc,gl_b,gc,H,L,Nb,Nc,R, ...
    Tl_by,Tcy,zeros(n,1),zeros(n,1),zeros(n,1),zeros(n,1));
Mjb9 = (Mjb9_1+Mjb9_2)/2;

% 限界補強量
% case2
Tbb9_1 = 1./(1+R.^2).*xi19_1.*b_c.*Db.*beta1*beta3.*fc-Thy/2+Mjb9_1./H;    % 式(8.37)
Tcb9_1 = 1./(1+1./R.^2).*xi19_1.*b_c.*Dc.*beta1*beta3.*fc-(Nc+Tmy)/2+Mjb9_1./L;  % 式(8.38)
Tbb9_2 = 1./(1+R.^2).*xi19_2.*b_c.*Db.*beta1*beta3.*fc-Thy/2+Mjb9_2./H;    % 式(8.37)
Tcb9_2 = 1./(1+1./R.^2).*xi19_2.*b_c.*Dc.*beta1*beta3.*fc-(Nc+Tmy)/2+Mjb9_2./L;  % 式(8.38)

% 接合部の終局モーメント：式(6)（Mju6_func.mのfunctionから計算式を引用）
[Mju6_1,Tb1_index,Tb2_index,Tc1_index,Tc2_index] = Mju6_func2(n, ...
    at_topb,Ac,b_b,b_c,beta3,Db,Dc,eps_u,Esb,Esc,fc,gu_b,gc,H,L,Nb,Nc, ...
    Tbb6_1,Tu_by,Tcb6_1,Tcy,Th1,Thy,Tm1,Tmy,Vb,Vc);
[Mju6_2,~,~,~,~] = Mju6_func2(n, ...
    at_btmb,Ac,b_b,b_c,beta3,Db,Dc,eps_u,Esb,Esc,fc,gl_b,gc,H,L,Nb,Nc, ...
    Tbb6_2,Tl_by,Tcb6_2,Tcy,Th2,Thy,Tm2,Tmy,Vb,Vc);
Mju6 = (Mju6_1+Mju6_2)/2;

% 接合部の終局モーメント：式(9)（Mju9_func.mのfunctionから計算式を引用）
[gamma_h1,gamma_v1,Mjh1,Mjv1,Mju9_1,Tb1_index9,Tc1_index9, ...
    Tb2_index9,Tc2_index9] = Mju9_func2020(n,at_topb,Ac,b_b,b_c,beta3, ...
    Db,Dc,eps_u,Esb,Esc,fc,gu_b,gc,H,L,Nc,Tbb9_1,Tu_by,Tcb9_1,Tcy,Thy,Tmy);
[gamma_h2,gamma_v2,Mjh2,Mjv2,Mju9_2,~,~, ...
    ~,~] = Mju9_func2020(n,at_btmb,Ac,b_b,b_c,beta3, ...
    Db,Dc,eps_u,Esb,Esc,fc,gl_b,gc,H,L,Nc,Tbb9_2,Tl_by,Tcb9_2,Tcy,Thy,Tmy);
Mju9 = (Mju9_1+Mju9_2)/2;

% 接合部の降伏モーメント：式(9)（Mjy9_func.mのfunctionから計算式を引用）
[~,~,~,~,Mjy1,~,~] = ...
    Mjy9_func2020(n,at_topb,Ac,b_b,b_c,beta3,Db,Dc,eps_u,Esb,Esc, ...
    fc,gu_b,gc,H,L,Nc,Tu_by,Tcy,Thy,Tmy);  % Tb=Tby，Tc=Tcyを強制的に代入
[~,~,~,~,Mjy2,~,~] = ...
    Mjy9_func2020(n,at_btmb,Ac,b_b,b_c,beta3,Db,Dc,eps_u,Esb,Esc, ...
    fc,gl_b,gc,H,L,Nc,Tl_by,Tcy,Thy,Tmy);  % Tb=Tby，Tc=Tcyを強制的に代入
Mjy = (Mjy1+Mjy2)/2;

% コンクリート強度データの有無確認（fc_data.mのfunctionから計算式を引用）
[Mu_b,Mu_c,Mjb6,Mjb9,Mju6,Mju9] = fc_data(n,fc_b,fc_c,fc,Mu_b,Mu_c,Mjb6,Mjb9,Mju6,Mju9);
% 梁，柱，接合部のコンクリートの圧縮強度のデータが揃っていないデータは，M=0としている
% -------------------------------------------------------------------------

% ◆◇ 計算結果出力 ◇◆ ---------------------------------------------------
Mbuf = Mu_b;                              % 梁の曲げ終局強度Mbuf（危険断面位置）
Mcuf = Mu_c;                              % 柱の曲げ終局強度Mcuf（危険断面位置）
Mbun = Mbuf.*L/2./sL;                     % 梁の曲げ終局強度Mbun（危険断面＝フェース→接合部中心＝節点）
Mcun = Mcuf.*H/2./sH;                     % 柱の曲げ終局強度Mcun（危険断面＝フェース→接合部中心＝節点）
TbbTby = (Tbb6_1+Tbb6_2)./(Tu_by+Tl_by);  % 釣合補強量と梁主筋の降伏強度の比Tbb/Tby
TcbTcy = (Tcb6_1+Tcb6_2)/2./Tcy;          % 釣合補強量と柱主筋の降伏強度の比Tcb/Tcy（ゼロ近傍や負になる場合もある）
ThcThy = (Th1+Th2)/2./Thy;                % ひずみの適合条件の有無による接合部横補強筋の応力の変化量
TmcTmy = (Tm1+Tm2)/2./Tmy;                % ひずみの適合条件の有無による柱中段筋の応力の変化量

% 曲げ強度比
McufMbuf = Mcuf./Mbuf;  % 柱梁曲げ強度比（危険断面）
McunMbun = Mcun./Mbun;  % 柱梁曲げ強度比（接合部中心）
MjuMbuf = Mju6./Mbuf;   % 接合部梁曲げ強度比（危険断面）
MjuMbun = Mju6./Mbun;   % 接合部梁曲げ強度比（接合部中心）
MjuMcuf = Mju6./Mcuf;   % 接合部柱曲げ強度比（危険断面）
MjuMcun = Mju6./Mcun;   % 接合部柱曲げ強度比（接合部中心）
MjuMjb = Mju6./Mjb6;    % 接合部終局強度Mjuと接合部釣合強度Mjbの比

Mjcal = zeros(n,15);
Mjcal(:,1) = no;                % 試験体番号
Mjcal(:,2) = Mju9/1000;         % 接合部終局強度
Mjcal(:,3) = 0;                 % 接合部釣合強度
Mjcal(:,4) = (Tbb9_1+Tbb9_2)./(Tu_by+Tl_by);  % 釣合補強量と梁主筋の降伏強度の比
Mjcal(:,5) = (Tcb9_1+Tcb9_2)/2./Tcy;  % 釣合補強量と柱主筋の降伏強度の比
Mjcal(:,6) = 0;                 % 接合部終局強度と接合部釣合強度の比
Mjcal(:,7) = MbunACI/1000;      % 梁の曲げ終局強度（接合部中心換算）
Mjcal(:,8) = McunACI/1000;      % 柱の曲げ終局強度（接合部中心換算）
Mjcal(:,9) = McunACI./MbunACI;  % 柱梁曲げ強度比（接合部中心）
Mjcal(:,10) = Mbun/1000;        % 梁の曲げ終局強度（接合部中心換算）
Mjcal(:,11) = Mcun/1000;        % 柱の曲げ終局強度（接合部中心換算）
Mjcal(:,12) = McunMbun;         % 柱梁曲げ強度比（接合部中心）
Mjcal(:,13) = Mjy/1000;         % 接合部降伏強度（Tb=Tby，Tc=Tcyを強制的に代入）
Mjcal(:,14) = Mju6/1000;        % ひずみの適合条件を考慮した接合部終局強度
Mjcal(:,15) = Mjb6/1000;        % ひずみの適合条件を考慮した接合部釣合強度

headers={'no','Mju','Mjb','TbbTby','TcbTcy','MjMjb','MbunACI','McunACI','McunMbunACI',...
    'Mbun','Mcun','McunMbun','MjTbyTcy','Mjucmp','Mjbcmp'};  % ヘッダー名
T=array2table(Mjcal,'VariableNames',headers);  % 配列変数をtable変数へ変換
writetable(T,'output_joint_zyuzi(exp).xlsx');  % Excelファイルへの計算結果の書き込み
% -------------------------------------------------------------------------

% ◆◇ 無次元パラメータの計算 ◇◆ ------------------------------------------
nw_b = fillmissing(dataset.n_b,'constant',0);     % あばら筋の本数
aw_b = fillmissing(dataset.bwbars,'constant',0);  % あばら筋1本当たりの公称断面積[mm2]
pic_b = fillmissing(dataset.picb,'constant',0);   % あばら筋の間隔
nw_c = fillmissing(dataset.n_c,'constant',0);     % 帯筋の本数
aw_c = fillmissing(dataset.a_h,'constant',0);     % 帯筋1本当たりの公称断面積[mm2]
pic_c = fillmissing(dataset.picc,'constant',0);   % 帯筋の間隔

% 梁主筋比（要変更箇所あり）
pt_b = at_btmb./(b_b.*(Db-d_btmb));  % 梁の引張鉄筋比[-]（有効せいdbを使用）
% pt_B = at_btmb./(b_b.*Db);         % 梁の引張鉄筋比[-]（梁せいDbを使用）
pt_B = Ab./(b_b.*Db);                % 梁の引張鉄筋比[-]（上段と下段の主筋量の平均をとる）
% qt_b = pt_B.*sigma_by./fc_b;       % 梁の鉄筋係数[-]
qt_b = pt_B.*sigma_by./fc;           % 梁の鉄筋係数[-]

% 柱主筋比（要変更箇所あり）
pt_c = Ac./(b_c.*(Dc-d_btmc));       % 柱の引張鉄筋比[-]
pg_c = ag_c./(b_c.*Dc);              % 柱の主筋比[-]
% qg_c = pg_c.*sigma_cy./fc_c;       % 柱の鉄筋係数[-]
qg_c = pg_c.*sigma_cy./fc;           % 柱の鉄筋係数[-]

% せん断補強筋比（横補強筋比）
pw_b = aw_b.*nw_b./(b_b.*pic_b);     % あばら筋比[-]
pw_c = aw_c.*nw_c./(b_c.*pic_c);     % 帯筋比[-]
pw_j = a_h.*n_h./(gb.*b_c.*Db);      % 接合部横補強筋比pjw[-]
qw_j = pw_j.*sigma_hy./fc;           % 接合部の鉄筋係数[-]

% 柱の軸力比や接合部アスペクト比（要変更箇所あり）
% eta = Nc./(b_c.*Dc.*fc_c);         % 柱の軸力比[-]
eta = Nc./(b_c.*Dc.*fc);             % 柱の軸力比[-]
R = Db./Dc;                          % 接合部アスペクト比[-]
bb_bc = b_b./b_c;                    % 梁柱幅比[-]
% Djb = Db; Djc = Dc;
% xi = Djb./Djc;
% xi_r = 1-1/2*(1-2*(xi+1./xi).^(-1));
% -------------------------------------------------------------------------

% ◆◇ グラフの作成 ◇◆ ---------------------------------------------------
% 降伏破壊と釣合破壊の境界の図示
if flg == 1
    fontsize = 20;                               % フォントサイズ
    set(figure,'Position',[0 580 440 420]);      % 新しいFigureウィンドウの作成，及びグラフの位置とサイズの指定
    hold on                                      % 現在の座標軸のプロットを保持
    x = [1,1];
    y = [0,1.2];
    plot(x,y,'g:','LineWidth',2)
    TcyTcb = 1./TcbTcy;
    TcyTcb9 = Tcy./((Tcb9_1+Tcb9_2)/2);
    MjuMcun9 = Mju9./Mcun;
    % plot(TcyTcb(McunMbun>1 & Tc1_index==0), ...
    %     MjuMcun(McunMbun>1 & Tc1_index==0), ...
    %     'o','MarkerSize',6,'MarkerEdgeColor',[0 0 1])  % 2次元プロットの作成
    % plot(TcyTcb(McunMbun>1 & Tc1_index==1), ...
    %     MjuMcun(McunMbun>1 & Tc1_index==1), ...
    %     'o','MarkerSize',6,'MarkerEdgeColor','#0072BD')  % 2次元プロットの作成
    plot(TcyTcb9(McunMbun>1 & Tc1_index9==0), ...
        MjuMcun9(McunMbun>1 & Tc1_index9==0), ...
        'o','MarkerSize',6,'MarkerEdgeColor',[1 0 0])  % 2次元プロットの作成
    plot(TcyTcb9(McunMbun>1 & Tc1_index9==1), ...
        MjuMcun9(McunMbun>1 & Tc1_index9==1), ...
        'o','MarkerSize',6,'MarkerEdgeColor','#EDB120')  % 2次元プロットの作成
    xlim([0 2])                                  % x軸の範囲の指定
    ylim([0 1.2])                                % y軸の範囲の指定
    ax = gca;
    ax.FontSize = 15;                            % 座標軸のフォントサイズ
    grid on                                      % グリッドラインの表示
    box on                                       % 座標軸の外枠の表示
    xlabel('$$T_{cy}/T_{cb}$$','interpreter','latex','FontSize',fontsize)  % x軸のラベル
    ylabel('$$M_{ju}/M_{cun}$$','interpreter','latex','FontSize',fontsize)  % y軸のラベル
    % xticks([0 0.5 1 1.5 2])                      % x軸の目盛り値の設定
    % yticks([0 0.5 1 1.5 2])                      % y軸の目盛り値の設定
end

% ひずみの適合条件を考慮した場合における，接合部横補強筋の応力Thの比較
if flg == 1
    fontsize = 20;                               % フォントサイズ
    set(figure,'Position',[440 580 440 420]);    % 新しいFigureウィンドウの作成，及びグラフの位置とサイズの指定
    hold on                                      % 現在の座標軸のプロットを保持
    x = [-1,1];
    y = [1,1];
    plot(x,y,'g:','LineWidth',2)
    Mju_cmp = Mju9./Mju6;
    map = lines;
    for i = 0:4
        % plot(ThcThy(McunMbun>1 & Tc1_index==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
        %     Mju_cmp(McunMbun>1 & Tc1_index==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
        %     'o','MarkerEdgeColor',map(i+1,:))  % 2次元プロットの作成
        plot(ThcThy(McunMbun>1 & Tc1_index9==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
            Mju_cmp(McunMbun>1 & Tc1_index9==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
            'o','MarkerEdgeColor',map(i+1,:))  % 2次元プロットの作成
    end
    xlim([0 1])                                  % x軸の範囲の指定
    ylim([0 1.4])                                % y軸の範囲の指定
    ax = gca;
    ax.FontSize = 15;                            % 座標軸のフォントサイズ
    grid on                                      % グリッドラインの表示
    box on                                       % 座標軸の外枠の表示
    xlabel('$$T_{hc}/T_{hy}$$','interpreter','latex','FontSize',fontsize)  % x軸のラベル
    ylabel('$$M_{ju}{\rm(case2)}/M_{ju}{\rm(cmp)}$$','interpreter','latex','FontSize',fontsize)  % y軸のラベル
    % xticks([0 0.5 1 1.5 2])                      % x軸の目盛り値の設定
    % yticks([0 0.5 1 1.5 2])                      % y軸の目盛り値の設定
end

% ひずみの適合条件を考慮した場合における，柱中段筋の応力Tmの比較
if flg == 1
    fontsize = 20;                               % フォントサイズ
    set(figure,'Position',[880 580 440 420]);    % 新しいFigureウィンドウの作成，及びグラフの位置とサイズの指定
    hold on                                      % 現在の座標軸のプロットを保持
    x = [-1,1];
    y = [1,1];
    plot(x,y,'g:','LineWidth',2)
    Mju_cmp = Mju9./Mju6;
    map = lines;
    for i = 0:4
        % plot(TmcTmy(McunMbun>1 & Tc1_index==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
        %     Mju_cmp(McunMbun>1 & Tc1_index==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
        %     'o','MarkerEdgeColor',map(i+1,:))  % 2次元プロットの作成
        plot(TmcTmy(McunMbun>1 & Tc1_index9==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
            Mju_cmp(McunMbun>1 & Tc1_index9==1 & eta>=i*0.1 & eta<i*0.1+0.1), ...
            'o','MarkerEdgeColor',map(i+1,:))  % 2次元プロットの作成
    end
    xlim([-1 1])                                 % x軸の範囲の指定
    ylim([0 1.4])                                % y軸の範囲の指定
    ax = gca;
    ax.FontSize = 15;                            % 座標軸のフォントサイズ
    grid on                                      % グリッドラインの表示
    box on                                       % 座標軸の外枠の表示
    xlabel('$$T_{mc}/T_{my}$$','interpreter','latex','FontSize',fontsize)  % x軸のラベル
    ylabel('$$M_{ju}{\rm(case2)}/M_{ju}{\rm(cmp)}$$','interpreter','latex','FontSize',fontsize)  % y軸のラベル
    % xticks([0 0.5 1 1.5 2])                      % x軸の目盛り値の設定
    % yticks([0 0.5 1 1.5 2])                      % y軸の目盛り値の設定
end
% -------------------------------------------------------------------------

fontsize = 20;                               % フォントサイズ
set(figure,'Position',[0 80 440 420]);       % 新しいFigureウィンドウの作成，及びグラフの位置とサイズの指定
hold on                                      % 現在の座標軸のプロットを保持
x = [0,5];
y = [1,1];
plot(x,y,'g:','LineWidth',2)
MbACIMb = Mbun./MbunACI;
map = lines;
plot(pt_b*100,MbACIMb,'o', ...
    'MarkerEdgeColor',map(1,:))              % 2次元プロットの作成
xlim([0 5])                                  % x軸の範囲の指定
ylim([0 2])                                  % y軸の範囲の指定
ax = gca;
ax.FontSize = 15;                            % 座標軸のフォントサイズ
grid on                                      % グリッドラインの表示
box on                                       % 座標軸の外枠の表示
xlabel('$$p_{tb}{\rm[\%]}$$','interpreter','latex','FontSize',fontsize)  % x軸のラベル
ylabel('$$M_{bun}/M_{bun}{\rm ACI}$$','interpreter','latex','FontSize',fontsize)  % y軸のラベル
% xticks([0 0.5 1 1.5 2])                      % x軸の目盛り値の設定
% yticks([0 0.5 1 1.5 2])                      % y軸の目盛り値の設定

fontsize = 20;                               % フォントサイズ
set(figure,'Position',[440 80 440 420]);     % 新しいFigureウィンドウの作成，及びグラフの位置とサイズの指定
hold on                                      % 現在の座標軸のプロットを保持
x = [0,8];
y = [1,1];
plot(x,y,'g:','LineWidth',2)
McACIMc = Mcun./McunACI;
map = lines;
plot(eta,McACIMc,'o', ...
    'MarkerEdgeColor',map(2,:))              % 2次元プロットの作成
plot(eta(n_top2c==0 & n_btm2c==0 & n_m==0),McACIMc(n_top2c==0 & n_btm2c==0 & n_m==0),'o', ...
    'MarkerEdgeColor',map(1,:))              % 2次元プロットの作成
plot(eta(sigma_cy>800),McACIMc(sigma_cy>800),'o', ...
    'MarkerEdgeColor','g')                   % 2次元プロットの作成
% plot(eta(fc_c>60),McACIMc(fc_c>60),'o', ...
%     'MarkerEdgeColor','g')                   % 2次元プロットの作成
xlim([0 0.4])                                % x軸の範囲の指定
ylim([0 2])                                  % y軸の範囲の指定
ax = gca;
ax.FontSize = 15;                            % 座標軸のフォントサイズ
grid on                                      % グリッドラインの表示
box on                                       % 座標軸の外枠の表示
xlabel('$$\eta$$','interpreter','latex','FontSize',fontsize)  % x軸のラベル
ylabel('$$M_{cun}/M_{cun}{\rm ACI}$$','interpreter','latex','FontSize',fontsize)  % y軸のラベル
% xticks([0 0.5 1 1.5 2])                      % x軸の目盛り値の設定
% yticks([0 0.5 1 1.5 2])                      % y軸の目盛り値の設定
% -------------------------------------------------------------------------

rmpath('./func');  % 検索パスからフォルダーを削除

toc  % ストップウォッチ開始からの経過時間を出力